DEFAULT_GUI_PORT = 8080
default_gui_port_ssl = 8443
DEFAULT_JOB_TABLE_PAGESIZE = 10
job_table_pagesize_key = "job_table_pagesize"
DEFAULT_RESULT_VIEWER_NUM_VAR_LIMIT_FOR_GENE_SUMMARY = 100000
result_viewer_num_var_limit_for_gene_summary_key = (
    "result_viewer_num_var_limit_for_gene_summary"
)
DEFAULT_RESULT_VIEWER_NUM_VAR_LIMIT_FOR_SUMMARY_WIDGET = 1000
result_viewer_num_var_limit_for_summary_widget_key = (
    "result_viewer_num_var_limit_for_summary_widget"
)
LOG_FN = "gui.log"
DEFAULT_PRIVATE_KEY = "default_private_key"
COOKIE_KEY = "oakvar_token"
WS_COOKIE_KEY = "ws_id"
SYSTEM_STATE_CONNECTION_KEY = "connection"
SYSTEM_STATE_SETUP_KEY = "setup"
SYSTEM_STATE_INSTALL_KEY = "install"
SYSTEM_STATE_INSTALL_QUEUE_KEY = "install_queue"
SYSTEM_MSG_KEY = "msg_kind"
SYSTEM_MESSAGE_DB_FNAME = "system_messages.sqlite"
SYSTEM_MESSAGE_TABLE = "system_messages"
SYSTEM_ERROR_TABLE = "system_errors"
INSTALL_KILL_SIGNAL = "kill_signal"
PORT_KEY = "port"
SYSCONF_PORT_KEY = "gui_port"
SYSCONF_SSL_PORT_KEY = "gui_port_ssl"
SYSCONF_HOST_KEY = "gui_host"
SYSCONF_SSL_HOST_KEY = "gui_host_ssl"
SSL_ENABELD_KEY = "ssl_enabled"
